@@ -25,25 +25,26 @@ from __future__ import division
 __all__ = ['alpha_Twu91_objf', 'alpha_Twu91_objfc', 'fit_function',
            'Twu91_check_params', 'postproc_lmfit',
            'alpha_poly_objf', 'alpha_poly_objfc', 'poly_check_params',
-           'fit_cheb_poly', 'poly_fit_statistics', 'fit_cheb_poly_auto',
+           'fit_polynomial', 'poly_fit_statistics', 'fit_cheb_poly_auto',
            'data_fit_statistics', 'fit_customized']
 
 from fluids.numerics import (chebval, brenth, third, sixth, roots_cubic,
                              roots_cubic_a1, numpy as np, newton,
                              bisect, inf, polyder, chebder, std, min_max_ratios,
-                             trunc_exp, secant, linspace, logspace,
+                             trunc_exp, secant, linspace, logspace, stable_poly_to_unstable,
                              horner, horner_and_der2, horner_and_der3,
                              is_poly_positive, is_poly_negative,
+                             horner_stable, horner_stable_and_der,
                              max_abs_error, max_abs_rel_error, max_squared_error, 
                              max_squared_rel_error, mean_abs_error, mean_abs_rel_error, 
                              mean_squared_error, mean_squared_rel_error,
                              curve_fit, differential_evolution, fit_minimization_targets, leastsq,
+                             polynomial_offset_scale,
                              lmder, lmfit)
 from fluids.constants import R
 import fluids, thermo
 try:
-    from numpy.polynomial.chebyshev import poly2cheb
-    from numpy.polynomial.chebyshev import cheb2poly
+    from numpy.polynomial.chebyshev import poly2cheb, cheb2poly, Chebyshev
     from numpy.polynomial.polynomial import Polynomial
 except:
     pass
@@ -53,10 +54,26 @@ except:
     pass
 
 ChebTools = None
-def fit_cheb_poly(func, low, high, n,
-                  interpolation_property=None, interpolation_property_inv=None,
-                  interpolation_x=lambda x: x, interpolation_x_inv=lambda x: x,
-                  arg_func=None):
+
+FIT_CHEBTOOLS_CHEB = 'ChebTools'
+FIT_CHEBTOOLS_POLY = 'ChebTools polynomial'
+FIT_CHEBTOOLS_STABLEPOLY = 'ChebTools stable polynomial'
+FIT_NUMPY_POLY = 'NumPy polynomial'
+FIT_NUMPY_STABLEPOLY = 'NumPy stable polynomial'
+
+
+FIT_METHOD_MAP = {FIT_CHEBTOOLS_CHEB: 'chebyshev',
+                  FIT_CHEBTOOLS_POLY: 'polynomial',
+                  FIT_CHEBTOOLS_STABLEPOLY: 'stablepolynomial',
+                  FIT_NUMPY_POLY:'polynomial',
+                  FIT_NUMPY_STABLEPOLY: 'stablepolynomial',
+                  }
+
+
+def fit_polynomial(func, low, high, n,
+                   interpolation_property=None, interpolation_property_inv=None,
+                   interpolation_x=lambda x: x, interpolation_x_inv=lambda x: x,
+                   arg_func=None, method=FIT_CHEBTOOLS_POLY):
     r'''Fit a function of one variable to a polynomial of degree `n` using the
     Chebyshev approximation technique. Transformations of the base function
     are allowed as lambdas.
@@ -94,6 +111,8 @@ def fit_cheb_poly(func, low, high, n,
     arg_func : None or callable
         Function which is called with the value of `x` in the original domain,
         and that returns arguments to `func`.
+    method : str
+        Which fitting method to use, [-]
 
     Returns
     -------
@@ -149,17 +168,31 @@ def fit_cheb_poly(func, low, high, n,
     func_fun = np.vectorize(func_fun)
     if n == 1:
         coeffs = [func_fun(0.5*(low + high)).tolist()]
+        return coeffs
     else:
-        cheb_fun = ChebTools.generate_Chebyshev_expansion(n-1, func_fun, low, high)
-
-        coeffs = cheb_fun.coef()
-        coeffs = cheb2poly(coeffs)[::-1].tolist() # Convert to polynomial basis
-    # Mix in low high limits to make it a normal polynomial
-    if high != low:
-        # Handle the case of no transformation, no limits
-        my_poly = Polynomial([-0.5*(high + low)*2.0/(high - low), 2.0/(high - low)])
-        coeffs = horner(coeffs, my_poly).coef[::-1].tolist()
-    return coeffs
+        if method in (FIT_CHEBTOOLS_CHEB, FIT_CHEBTOOLS_POLY, FIT_CHEBTOOLS_STABLEPOLY):
+            cheb_fun = ChebTools.generate_Chebyshev_expansion(n-1, func_fun, low, high)
+            cheb_coeffs = cheb_fun.coef()
+            
+            if method == FIT_CHEBTOOLS_STABLEPOLY or method == FIT_CHEBTOOLS_POLY:
+                coeffs = cheb2poly(cheb_coeffs)[::-1].tolist()
+            if method == FIT_CHEBTOOLS_CHEB:
+                return cheb_coeffs.tolist()
+            elif method == FIT_CHEBTOOLS_STABLEPOLY:
+            # Can use Polynomial(coeffs[::-1], domain=(low, high)) to evaluate, or horner_domain(x, coeffs, xmin, xmax)
+                return coeffs
+            elif method == FIT_CHEBTOOLS_POLY:
+                return stable_poly_to_unstable(coeffs, low, high)
+        elif method in (FIT_NUMPY_POLY, FIT_NUMPY_STABLEPOLY):
+            x = linspace(low, high, 200)
+            y = [func_fun(xi) for xi in x]
+            fit = Polynomial.fit(x, y, n)
+            coeffs = fit.coef
+            coeffs = coeffs[::-1].tolist()
+            if method == FIT_NUMPY_STABLEPOLY:
+                return coeffs
+            elif method == FIT_NUMPY_POLY:
+                return stable_poly_to_unstable(coeffs, low, high)
 
 def data_fit_statistics(xs, actual_pts, calc_pts):
     pts = len(xs)
@@ -177,7 +210,7 @@ def data_fit_statistics(xs, actual_pts, calc_pts):
 def poly_fit_statistics(func, coeffs, low, high, pts=200,
                         interpolation_property_inv=None,
                         interpolation_x=lambda x: x,
-                        arg_func=None):
+                        arg_func=None, method='polynomial'):
     r'''Function to check how accurate a fit function is to a polynomial.
 
     This function uses the asolute relative error definition.
@@ -207,6 +240,9 @@ def poly_fit_statistics(func, coeffs, low, high, pts=200,
     arg_func : None or callable
         Function which is called with the value of `x` in the original domain,
         and that returns arguments to `func`.
+    method : str
+        Which type of polynomial the coefficients are;
+        one of 'polynomial', 'stablepolynomial', 'chebyshev' [-]
 
     Returns
     -------
@@ -229,9 +265,18 @@ def poly_fit_statistics(func, coeffs, low, high, pts=200,
     # Get the low, high, and x points in the transformed domain
     low, high = interpolation_x(low_orig), interpolation_x(high_orig)
     all_points = [interpolation_x(v) for v in all_points_orig]
+    offset, scale = polynomial_offset_scale(low, high)
+
+    if method in FIT_METHOD_MAP:
+        method = FIT_METHOD_MAP[method]
 
     # Calculate the fit values
-    calc_pts = [horner(coeffs, x) for x in all_points]
+    if method == 'polynomial':
+        calc_pts = [horner(coeffs, x) for x in all_points]
+    elif method == 'stablepolynomial':
+        calc_pts = [horner_stable(x, coeffs, offset, scale) for x in all_points]
+    elif method == 'chebyshev':
+        calc_pts = [chebval(x, coeffs, offset, scale) for x in all_points]
     if interpolation_property_inv:
         for i in range(pts):
             calc_pts[i] = interpolation_property_inv(calc_pts[i])
@@ -278,17 +323,19 @@ def select_index_from_stats(stats, ns):
 def fit_many_cheb_poly(func, low, high, ns, eval_pts=30,
                   interpolation_property=None, interpolation_property_inv=None,
                   interpolation_x=lambda x: x, interpolation_x_inv=lambda x: x,
-                  arg_func=None):
+                  arg_func=None, method=FIT_CHEBTOOLS_POLY):
 
     def a_fit(n, eval_pts=eval_pts):
-        coeffs = fit_cheb_poly(func, low, high, n,
-                  interpolation_property=interpolation_property, interpolation_property_inv=interpolation_property_inv,
-                  interpolation_x=interpolation_x, interpolation_x_inv=interpolation_x_inv,
-                  arg_func=arg_func)
+        coeffs = fit_polynomial(func, low, high, n,
+                                interpolation_property=interpolation_property, interpolation_property_inv=interpolation_property_inv,
+                                interpolation_x=interpolation_x, interpolation_x_inv=interpolation_x_inv,
+                                arg_func=arg_func, method=method)
+
+        method2 = FIT_METHOD_MAP[method]
         err_avg, err_std, min_ratio, max_ratio = poly_fit_statistics(func, coeffs, low, high, pts=eval_pts,
                                 interpolation_property_inv=interpolation_property_inv,
                                 interpolation_x=interpolation_x,
-                                arg_func=arg_func)
+                                arg_func=arg_func, method=method2)
         return coeffs, err_avg, err_std, min_ratio, max_ratio
 
     worked_ns, worked_coeffs, worked_stats = [], [], []
@@ -307,11 +354,11 @@ def fit_many_cheb_poly(func, low, high, ns, eval_pts=30,
 def fit_cheb_poly_auto(func, low, high, start_n=3, max_n=20, eval_pts=100,
                   interpolation_property=None, interpolation_property_inv=None,
                   interpolation_x=lambda x: x, interpolation_x_inv=lambda x: x,
-                  arg_func=None):
+                  arg_func=None, method=FIT_CHEBTOOLS_POLY):
     worked_ns, worked_coeffs, worked_stats = fit_many_cheb_poly(func, low, high, ns=range(start_n, max_n+1),
                   interpolation_property=interpolation_property, interpolation_property_inv=interpolation_property_inv,
                   interpolation_x=interpolation_x, interpolation_x_inv=interpolation_x_inv,
-                  arg_func=arg_func, eval_pts=eval_pts)
+                  arg_func=arg_func, eval_pts=eval_pts, method=method)
     idx = select_index_from_stats(worked_stats, worked_ns)
 
     return worked_ns[idx], worked_coeffs[idx], worked_stats[idx]
@@ -550,7 +597,8 @@ def fit_customized(Ts, data, fitting_func, fit_parameters, use_fit_parameters,
                    guesses=None, initial_guesses=None, analytical_jac=None,
                    solver_kwargs=None, use_numba=False, multiple_tries=False,
                    do_statistics=False, multiple_tries_max_err=1e-5,
-                   func_wrapped_for_leastsq=None, jac_wrapped_for_leastsq=None):
+                   func_wrapped_for_leastsq=None, jac_wrapped_for_leastsq=None,
+                   sigma=None):
     if solver_kwargs is None: solver_kwargs = {}
     if use_numba:
         fit_func_dict = fluids.numba.numerics.fit_minimization_targets
@@ -636,7 +684,7 @@ def fit_customized(Ts, data, fitting_func, fit_parameters, use_fit_parameters,
                                       bounds=working_bounds, **solver_kwargs)
         popt = res['x']
     else:
-        lm_direct = fit_method == 'lm'
+        lm_direct = (fit_method == 'lm' and sigma is None)
         Dfun = jac_wrapped_for_leastsq if analytical_jac is not None else None
         if 'maxfev' not in solver_kwargs and fit_method == 'lm':
             # DO NOT INCREASE THIS! Make an analytical jacobian instead please.
@@ -664,8 +712,8 @@ def fit_customized(Ts, data, fitting_func, fit_parameters, use_fit_parameters,
 
                         pcov = None
                     else:
-                        popt, pcov = curve_fit(fitting_func, Ts, data, p0=p0, jac=analytical_jac, 
-                                                method=fit_method, **solver_kwargs)
+                        popt, pcov = curve_fit(fitting_func, Ts, data, sigma=sigma, p0=p0, jac=analytical_jac, 
+                                                method=fit_method, absolute_sigma=True, **solver_kwargs)
                 except:
                     continue
                 calc = fitting_func(Ts, *popt)
@@ -685,8 +733,8 @@ def fit_customized(Ts, data, fitting_func, fit_parameters, use_fit_parameters,
                 popt, _ = leastsq(func_wrapped_for_leastsq, p0, Dfun=Dfun, **solver_kwargs)
                 pcov = None
             else:
-                popt, pcov = curve_fit(fitting_func, Ts, data, p0=p0, jac=analytical_jac,
-                                        method=fit_method, **solver_kwargs)
+                popt, pcov = curve_fit(fitting_func, Ts, data, sigma=sigma, p0=p0, jac=analytical_jac,
+                                        method=fit_method, absolute_sigma=True, **solver_kwargs)
     out_kwargs = {}
     for param_name, param_value in zip(fit_parameters, popt):
         out_kwargs[param_name] = float(param_value)
