@@ -39,11 +39,17 @@ please use the `GitHub issue tracker <https://github.com/CalebBell/thermo/>`_.
    Exmple database with NRTL and PR values from ChemSep. This is lazy-loaded,
    access it as `thermo.interaction_parameters.IPDB`.
 
+.. autoclass:: ScalarParameterDB
+
+SPDB
+
+    Example scalar parameters for models. This is lazy-loaded,
+    access it as `thermo.interaction_parameters.SPDB`.
 '''
 
 from __future__ import division
 
-__all__ = ['InteractionParameterDB']
+__all__ = ['InteractionParameterDB', 'ScalarParameterDB']
 
 import os
 from math import isnan
@@ -346,6 +352,209 @@ class InteractionParameterDB(object):
                 values[i][j] = i_ip
         return values
 
+class ScalarParameterDB(object):
+    '''Basic database framework for scalar parameters of various thermodynamic
+    models. The following keys are used:
+    
+    **Peng-Robinson**
+    
+    :obj:`Twu Volume-translated Peng-Robinson <thermo.eos_mix.PRMIXTranslatedConsistent>`:
+    `TwuPRL`, `TwuPRM`, `TwuPRN`, `TwuPRc`
+    
+    :obj:`Volume-translated Peng-Robinson <thermo.eos_mix.PRMIXTranslated>`:
+    `PRc`
+    
+    :obj:`Peng-Robinson-Stryjek-Vera  <thermo.eos_mix.PRSVMIX>`:
+    `PRSVkappa1`
+    
+    :obj:`Peng-Robinson-Stryjek-Vera 2  <thermo.eos_mix.PRSV2MIX>`:
+    `PRSV2kappa1`, `PRSV2kappa2`, `PRSV2kappa3`
+    
+    **SRK**
+    
+    :obj:`Twu Volume-translated Peng-Robinson <thermo.eos_mix.SRKMIXTranslatedConsistent>`:
+    `TwuSRKL`, `TwuSRKM`, `TwuSRKN`, `TwuSRKc`
+    
+    :obj:`Volume-translated Peng-Robinson <thermo.eos_mix.SRKMIXTranslated>`:
+    `SRKc`
+
+    :obj:`Refinery Soave-Redlich-Kwong  <thermo.eos_mix.APISRKMIX>`:
+    `APISRKS1`, `APISRKS2`
+    
+    :obj:`MSRK  <thermo.eos_mix.MSRKMIXTranslated>`:
+    `MSRKM`, `MSRKN`, `MSRKc`
+
+    :obj:`Predictive Soave-Redlich-Kwong <thermo.eos_mix.PSRK>`:
+    `MCSRKC1`, `MCSRKC2`, `MCSRKC3`
+
+    
+    **Excess Gibbs Energy Models**
+    
+    :obj:`Regular Solution <thermo.regular_solution.RegularSolution>`:
+    `RegularSolutionV`, `RegularSolutionSP`
+    
+        
+    '''
+    def __init__(self):
+        self.tables = {}
+        self.metadata = {}
+    def load_json(self, file, name):
+        
+        import json
+        f = open(file).read()
+        dat = json.loads(f)
+        self.tables[name] = dat['data']
+        self.metadata[name] = dat['metadata']
+        
+    def get_parameter_specific(self, name, CAS, parameter):
+        '''Get a parameter from a table. If the specified
+        parameter is missing, the default `missing` value as defined in
+        the data file is returned instead.
+
+        Parameters
+        ----------
+        name : str
+            Name of the data table, [-]
+        CAS : str
+            CAS number, [-]
+        parameter : str
+            Name of the parameter to retrieve, [-]
+
+        Returns
+        -------
+        value : float
+            Interaction parameter specified by `ip`, [-]
+
+        Examples
+        --------
+        Get the `L` Twu parameter for PR from Piña-Martinez (2021):
+
+        >>> from thermo.interaction_parameters import SPDB
+        >>> SPDB.get_parameter_specific('PRTwu_PinaMartinez', '7727-37-9', 'TwuPRL')
+        0.1243
+        '''
+        try:
+            return self.tables[name][CAS][parameter]
+        except KeyError:
+            return self.metadata[name]['missing'][parameter]
+
+    def has_parameter_specific(self, name, CAS, parameter):
+        '''Check if a parameter exists in a table.
+
+        Parameters
+        ----------
+        name : str
+            Name of the data table, [-]
+        CAS : str
+            CAS number, [-]
+        parameter : str
+            Name of the parameter to retrieve, [-]
+
+        Returns
+        -------
+        present : bool
+            Whether or not the data is included in the table, [-]
+
+        Examples
+        --------
+
+        >>> from thermo.interaction_parameters import SPDB
+        >>> SPDB.has_parameter_specific('PRTwu_PinaMartinez', '7727-37-9', 'TwuPRL')
+        True
+        >>> SPDB.has_parameter_specific('PRTwu_PinaMartinez', '7439-89-6', 'TwuPRL')
+        False
+        '''
+        table = self.tables[name]
+        if CAS not in table:
+            return False
+        return parameter in table[CAS]
+
+    def get_tables_with_type(self, parameter):
+        '''Get a list of tables which have a parameter.
+
+        Parameters
+        ----------
+        parameter : str
+            Name of the parameter, [-]
+
+        Returns
+        -------
+        table_names : list[str]
+            Interaction parameter tables including `parameter`, [-]
+
+        Examples
+        --------
+
+        >>> from thermo.interaction_parameters import SPDB
+        >>> SPDB.get_tables_with_type('TwuPRL')
+        ['PRTwu_PinaMartinez', 'PRTwu_ibell_2018']
+        '''
+        tables = []
+        for key, d in self.metadata.items():
+            if parameter in d['missing']:
+                tables.append(key)
+        return tables
+
+    def get_parameter_automatic(self, CAS, parameter):
+        '''Get an interaction parameter for the first table containing the
+        value.
+
+        Parameters
+        ----------
+        CAS : str
+            CAS number, [-]
+        parameter : str
+            Name of the parameter to retrieve, [-]
+
+        Returns
+        -------
+        value : float
+            Parameter value specified by `parameter`, [-]
+
+        Examples
+        --------
+
+        >>> from thermo.interaction_parameters import SPDB
+        >>> SPDB.get_parameter_automatic('7727-37-9', parameter='TwuPRL')
+        0.1243
+        '''
+        table = self.get_tables_with_type(parameter)[0]
+        return self.get_parameter_specific(table, CAS, parameter)
+
+    def get_parameter_vector(self, name, CASs, parameter):
+        '''Get a list of parameters from a specified source
+        for the specified parameter.
+
+        Parameters
+        ----------
+        name : str
+            Name of the data table, [-]
+        CASs : Iterable[str]
+            CAS numbers; the returned values will be in this order, [-]
+        parameter : str
+            Name of the parameter to retrieve, [-]
+
+        Returns
+        -------
+        values : list[float]
+            Parameter specified by `parameter`, [-]
+
+        Examples
+        --------
+
+        >>> from thermo.interaction_parameters import SPDB
+        >>> SPDB.get_parameter_vector(name='PRTwu_PinaMartinez', CASs=['7727-37-9', '74-84-0', '74-98-6'], parameter='TwuPRL')
+        [0.1243, 0.3053, 0.7455]
+        >>> SPDB.get_parameter_vector(name='PRVolumeTranslation_PinaMartinez', CASs=['7727-37-9', '74-84-0', '74-98-6'], parameter='PRc')
+        [-3.643e-06, -3.675e-06, -3.735e-06]
+        '''
+        table = self.tables[name]
+        N = len(CASs)
+        values = [None]*N
+        for i in range(N):
+            values[i] = self.get_parameter_specific(name, CASs[i], parameter)
+        return values
+
 
 _loaded_interactions = False
 def load_all_interaction_parameters():
@@ -366,12 +575,39 @@ def load_all_interaction_parameters():
 
     _loaded_interactions = True
 
+_loaded_scalars = False
+def load_all_scalar_parameters():
+    global SPDB, _loaded_scalars
+
+    folder = os.path.join(os.path.dirname(__file__), 'Scalar Parameters')
+    sp_files = {'PRTwu_PinaMartinez': os.path.join(folder, 'PRTwu_PinaMartinez.json'),
+                'SRKTwu_PinaMartinez': os.path.join(folder, 'SRKTwu_PinaMartinez.json'),
+                'PRVolumeTranslation_PinaMartinez': os.path.join(folder, 'PRVolumeTranslation_PinaMartinez.json'),
+                'SRKVolumeTranslation_PinaMartinez': os.path.join(folder, 'SRKVolumeTranslation_PinaMartinez.json'),
+                'PRTwu_ibell_2018': os.path.join(folder, 'PRTwu_ibell_2018.json'),
+
+                'chemsep_regular_solution': os.path.join(folder, 'chemsep_regular_solution.json'),
+                'chemsep_PSRK_matthias_copeman': os.path.join(folder, 'chemsep_PSRK_matthias_copeman.json'),
+                'chemsep_APISRK': os.path.join(folder, 'chemsep_APISRK.json'),
+                }
+
+
+    SPDB = ScalarParameterDB()
+    for name, file in sp_files.items():
+        SPDB.load_json(file, name)
+
+    _loaded_scalars = True
+
 if PY37:
     def __getattr__(name):
         if name in ('IPDB',):
             load_all_interaction_parameters()
             return globals()[name]
+        if name in ('SPDB',):
+            load_all_scalar_parameters()
+            return globals()[name]
         raise AttributeError("module %s has no attribute %s" %(__name__, name))
 else:
     if can_load_data:
         load_all_interaction_parameters()
+        load_all_scalar_parameters()
