@@ -122,7 +122,12 @@ def set_coolprop_constants():
             AS.specify_phase(phase)
             if zs is not None:
                 AS.set_mole_fractions(zs)
-            AS.update(spec_set, spec0, spec1) # A failed call here takes ~400 us.
+            try:
+                AS.update(spec_set, spec0, spec1) # A failed call here takes ~400 us.
+            except:
+                # The best workaround is to impose a different phase with CoolProp
+                AS.specify_phase(CPliquid if phase == CPgas else CPgas)
+                AS.update(spec_set, spec0, spec1)
             caching_states_CoolProp[key] = AS
             return AS
         else:
@@ -449,9 +454,12 @@ class CoolPropPhase(Phase):
 
     def dS_dT(self):
         return self.AS.first_partial_deriv(CPiSmolar, CPiT, CPiP)
+    dS_dT_P = dS_dT
 
     def dS_dP(self):
         return self.AS.first_partial_deriv(CPiSmolar, CPiP, CPiT)
+    
+    dS_dP_T = dS_dP
 
     def dS_dT_V(self):
         return self.AS.first_partial_deriv(CPiSmolar, CPiT, CPiDmolar)
